@@ -1,15 +1,14 @@
-from Products.CMFPlone.interfaces import ISiteSchema
+# -*- coding: utf-8 -*-
 from plone.registry.interfaces import IRegistry
-
+from Products.CMFPlone.interfaces import ISiteSchema
+from Products.Five.browser import BrowserView
 from zope.component import getUtility
-from zope.interface import implements
+from zope.interface import implementer
 from zope.viewlet.interfaces import IViewlet
 
-from Products.Five.browser import BrowserView
-
 
+@implementer(IViewlet)
 class AnalyticsViewlet(BrowserView):
-    implements(IViewlet)
 
     def __init__(self, context, request, view, manager):
         super(AnalyticsViewlet, self).__init__(context, request)
@@ -25,10 +24,11 @@ class AnalyticsViewlet(BrowserView):
     def render(self):
         """render the webstats snippet"""
         registry = getUtility(IRegistry)
-        site_settings = registry.forInterface(ISiteSchema, prefix="plone", check=False)
+        site_settings = registry.forInterface(
+            ISiteSchema, prefix="plone", check=False)
         try:
             if site_settings.webstats_js:
                 return site_settings.webstats_js
-            return ''
         except AttributeError:
-            return ''
+            pass
+        return ''
